@@ -68,7 +68,7 @@ class Sqlite:
 
         self.table_name = table if table else self.table_name
         value_str = "({})".format(
-            ",".join(list(map(lambda x: f"'{x}'" if x is not None else "NULL", columns_list))))
+            ",".join(list(map(self.get_insert_value, columns_list))))
         self.column_name_list = columns_dict.keys() if len(columns_dict) else []
         self.column_name_str = ",".join(self.column_name_list)
         self.column_name_str = f"({self.column_name_str})" if len(
@@ -152,6 +152,13 @@ class Sqlite:
     def output_sql(self) -> None:
         self.sql_show = True
 
+    def get_insert_value(self, value) -> str:
+        if value is not None:
+            value = str(value).replace(r"'", r"\'")
+            return f"'{value}'"
+        else:
+            return "NULL"
+
     def __del__(self):
         if not self.db and not self:
             self.close_connect()
